==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/component/AutoRequestData.java <==
package com.zurrtum.create.infrastructure.component;

import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import com.zurrtum.create.AllDataComponents;
import net.minecraft.class_124;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_5250;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;

public record AutoRequestData(
    PackageOrderWithCrafts encodedRequest, String encodedTargetAddress, class_2338 targetOffset, String targetDim, boolean isValid
) {

    public static final Codec<AutoRequestData> CODEC = RecordCodecBuilder.create(instance -> instance.group(
        PackageOrderWithCrafts.CODEC.fieldOf("encoded_request").forGetter(AutoRequestData::encodedRequest),
        Codec.STRING.fieldOf("encoded_target_address").forGetter(AutoRequestData::encodedTargetAddress),
        class_2338.field_25064.fieldOf("target_offset").forGetter(AutoRequestData::targetOffset),
        Codec.STRING.fieldOf("target_dim").forGetter(AutoRequestData::targetDim),
        Codec.BOOL.fieldOf("is_valid").forGetter(AutoRequestData::isValid)
    ).apply(instance, AutoRequestData::new));

    public static final class_9139<class_9129, AutoRequestData> STREAM_CODEC = class_9139.method_56906(
        PackageOrderWithCrafts.STREAM_CODEC,
        AutoRequestData::encodedRequest,
        class_9135.field_48554,
        AutoRequestData::encodedTargetAddress,
        class_2338.field_48404,
        AutoRequestData::targetOffset,
        class_9135.field_48554,
        AutoRequestData::targetDim,
        class_9135.field_48547,
        AutoRequestData::isValid,
        AutoRequestData::new
    );

    public AutoRequestData() {
        this(PackageOrderWithCrafts.empty(), "", class_2338.field_10980, "null", false);
    }

    public void writeToItem(class_2338 position, class_1799 itemStack) {
        Mutable mutable = new Mutable(this);
        mutable.targetOffset = position.method_10081(targetOffset);
        itemStack.method_57379(AllDataComponents.AUTO_REQUEST_DATA, mutable.toImmutable());
    }

    public static AutoRequestData readFromItem(class_1937 level, class_1657 player, class_2338 position, class_1799 itemStack) {
        AutoRequestData requestData = itemStack.method_58694(AllDataComponents.AUTO_REQUEST_DATA);
        if (requestData == null)
            return null;

        Mutable mutable = new Mutable(requestData);

        mutable.targetOffset = mutable.targetOffset.method_10059(position);
        mutable.isValid = mutable.targetOffset.method_19771(class_2338.field_11176, 128) && requestData.targetDim.equals(level.method_27983().method_29177()
            .toString());

        if (player != null) {
            class_5250 message = mutable.isValid ? class_2561.method_43471("create.redstone_requester.keeper_connected")
                .method_27692(class_124.field_1068) : class_2561.method_43471("create.redstone_requester.keeper_too_far_away").method_27692(class_124.field_1061);
            player.method_7353(message, true);
        }

        return mutable.toImmutable();
    }

    public static class Mutable {
        public PackageOrderWithCrafts encodedRequest = PackageOrderWithCrafts.empty();
        public String encodedTargetAddress = "";
        public class_2338 targetOffset = class_2338.field_10980;
        public String targetDim = "null";
        public boolean isValid = false;

        public Mutable() {
        }

        public Mutable(AutoRequestData data) {
            encodedRequest = data.encodedRequest;
            encodedTargetAddress = data.encodedTargetAddress;
            targetOffset = data.targetOffset;
            targetDim = data.targetDim;
            isValid = data.isValid;
        }

        public AutoRequestData toImmutable() {
            return new AutoRequestData(encodedRequest, encodedTargetAddress, targetOffset, targetDim, isValid);
        }
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/infrastructure/component/AutoRequestData.java <==
package com.zurrtum.create.infrastructure.component;

import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import com.zurrtum.create.AllDataComponents;
import net.minecraft.class_124;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_5250;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;

public record AutoRequestData(
    PackageOrderWithCrafts encodedRequest, String encodedTargetAddress, class_2338 targetOffset, String targetDim, boolean isValid
) {

    public static final Codec<AutoRequestData> CODEC = RecordCodecBuilder.create(instance -> instance.group(
        PackageOrderWithCrafts.CODEC.fieldOf("encoded_request").forGetter(AutoRequestData::encodedRequest),
        Codec.STRING.fieldOf("encoded_target_address").forGetter(AutoRequestData::encodedTargetAddress),
        class_2338.field_25064.fieldOf("target_offset").forGetter(AutoRequestData::targetOffset),
        Codec.STRING.fieldOf("target_dim").forGetter(AutoRequestData::targetDim),
        Codec.BOOL.fieldOf("is_valid").forGetter(AutoRequestData::isValid)
    ).apply(instance, AutoRequestData::new));

    public static final class_9139<class_9129, AutoRequestData> STREAM_CODEC = class_9139.method_56906(
        PackageOrderWithCrafts.STREAM_CODEC,
        AutoRequestData::encodedRequest,
        class_9135.field_48554,
        AutoRequestData::encodedTargetAddress,
        class_2338.field_48404,
        AutoRequestData::targetOffset,
        class_9135.field_48554,
        AutoRequestData::targetDim,
        class_9135.field_48547,
        AutoRequestData::isValid,
        AutoRequestData::new
    );

    public AutoRequestData() {
        this(PackageOrderWithCrafts.empty(), "", class_2338.field_10980, "null", false);
    }

    public void writeToItem(class_2338 position, class_1799 itemStack) {
        Mutable mutable = new Mutable(this);
        mutable.targetOffset = position.method_10081(targetOffset);
        itemStack.method_57379(AllDataComponents.AUTO_REQUEST_DATA, mutable.toImmutable());
    }

    public static AutoRequestData readFromItem(class_1937 level, class_1657 player, class_2338 position, class_1799 itemStack) {
        AutoRequestData requestData = itemStack.method_58694(AllDataComponents.AUTO_REQUEST_DATA);
        if (requestData == null)
            return null;

        Mutable mutable = new Mutable(requestData);

        mutable.targetOffset = mutable.targetOffset.method_10059(position);
        mutable.isValid = mutable.targetOffset.method_19771(class_2338.field_10980, 128) && requestData.targetDim.equals(level.method_27983().method_29177()
            .toString());

        if (player != null) {
            class_5250 message = mutable.isValid ? class_2561.method_43471("create.redstone_requester.keeper_connected")
                .method_27692(class_124.field_1068) : class_2561.method_43471("create.redstone_requester.keeper_too_far_away")
                .method_27692(class_124.field_1061);
            player.method_7353(message, true);
        }

        return mutable.toImmutable();
    }

    public static class Mutable {
        public PackageOrderWithCrafts encodedRequest = PackageOrderWithCrafts.empty();
        public String encodedTargetAddress = "";
        public class_2338 targetOffset = class_2338.field_10980;
        public String targetDim = "null";
        public boolean isValid = false;

        public Mutable() {
        }

        public Mutable(AutoRequestData data) {
            encodedRequest = data.encodedRequest;
            encodedTargetAddress = data.encodedTargetAddress;
            targetOffset = data.targetOffset;
            targetDim = data.targetDim;
            isValid = data.isValid;
        }

        public AutoRequestData toImmutable() {
            return new AutoRequestData(encodedRequest, encodedTargetAddress, targetOffset, targetDim, isValid);
        }
    }
}
